from typing import Literal

BackgroundRepeat = Literal[
    'repeat',
    'no-repeat',
    'repeat-x',
    'repeat-y',
    'repeat-round',
    'repeat-space',
]
